@@ -6,7 +6,7 @@
  * Date        : 2008-10-02
  * Description : a kipi plugin to slide images.
  *
- * Copyright (C) 2008 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
+ * Copyright (C) 2008-2009 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -71,17 +71,7 @@ SharedData::SharedData()
 
 SharedData::~SharedData()
 {
-//    if ( mainPage ) delete mainPage;
-//    if ( captionPage ) delete captionPage;
-//    if ( soundtrackPage ) delete soundtrackPage;
-//    if ( advancedPage ) delete advancedPage;
-//
-//    if ( page_main ) delete page_main;
-//    if ( page_caption ) delete page_caption;
-//    if ( page_soundtrack ) delete page_soundtrack;
-//    if ( page_advanced ) delete page_advanced;
-//
-//    if ( captionFont ) delete captionFont;
+    delete captionFont;
 }
 
 VolumeSlider::VolumeSlider(QWidget* parent)
