@@ -6,7 +6,7 @@
  * Date        : 2008-10-02
  * Description : a kipi plugin to slide images.
  *
- * Copyright (C) 2008 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
+ * Copyright (C) 2008-2009 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -54,15 +54,10 @@ namespace KIPIAdvancedSlideshowPlugin
 {
 
 class MainDialog;
-
 class CaptionDialog;
-
 class SoundtrackDialog;
-
 class AdvancedDialog;
-
 class PlaybackWidget;
-
 class SharedData
 {
 
@@ -80,7 +75,7 @@ public:
     int                  delayMsLineStep;
 
     bool                 ImagesHasComments;
-    KUrl::List*          urlList;
+    KUrl::List           urlList;
 
     MainDialog*          mainPage;
     CaptionDialog*       captionPage;
@@ -94,37 +89,38 @@ public:
 
     // Config file data
     // --> Main page
-    bool             opengl;
-    int              delay;
-    bool             printFileName;
-    bool             printProgress;
-    bool             printFileComments;
-    bool             loop;
-    bool             shuffle;
-    bool             showSelectedFilesOnly;
-    QString          effectName;
-    QString          effectNameGL;
+    bool                 opengl;
+    int                  delay;
+    bool                 printFileName;
+    bool                 printProgress;
+    bool                 printFileComments;
+    bool                 loop;
+    bool                 shuffle;
+    bool                 showSelectedFilesOnly;
+    QString              effectName;
+    QString              effectNameGL;
     // --> Captions page
-    uint             commentsFontColor;
-    uint             commentsBgColor;
-    bool             transparentBg;
-    int              commentsLinesLength;
-    QFont*           captionFont;
+    uint                 commentsFontColor;
+    uint                 commentsBgColor;
+    bool                 transparentBg;
+    int                  commentsLinesLength;
+    QFont*               captionFont;
     // --> Soundtrack page
-    bool             soundtrackLoop;
-    KUrl             soundtrackPath;
-    KUrl::List       soundtrackUrls;
+    bool                 soundtrackLoop;
+    KUrl                 soundtrackPath;
+    KUrl::List           soundtrackUrls;
 
     // --> Advanced page
-    bool             useMilliseconds;
-    bool             enableMouseWheel;
-    bool             enableCache;
-    bool             kbDisableFadeInOut;
-    bool             kbDisableCrossFade;
-    uint             cacheSize;
-
+    bool                 useMilliseconds;
+    bool                 enableMouseWheel;
+    bool                 enableCache;
+    bool                 kbDisableFadeInOut;
+    bool                 kbDisableCrossFade;
+    uint                 cacheSize;
 };
 
+// ----------------------------------------------------------
+
 class VolumeSlider : public Phonon::VolumeSlider
 {
 
