@@ -6,7 +6,8 @@
  * Date        : 2008-09-09
  * Description : a kipi plugin to slide images.
  *
- * Copyright (C) 2008 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
+ * Copyright (C) 2008-2009 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
+ * Copyright (C) 2009 by Andi Clemens <andi dot clemens at gmx dot net>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -33,6 +34,8 @@
 #include <QString>
 #include <QStringList>
 #include <QTime>
+#include <QHeaderView>
+#include <QPainter>
 
 // KDE includes
 
@@ -46,10 +49,12 @@
 // Local includes
 
 #include "imagedialog.h"
-#include "listimageitems.h"
 #include "slideshow.h"
 #include "slideshowgl.h"
 #include "slideshowkb.h"
+#include "imageslist.h"
+
+using namespace KIPIPlugins;
 
 namespace KIPIAdvancedSlideshowPlugin
 {
@@ -62,6 +67,19 @@ MainDialog::MainDialog( QWidget* parent, SharedData* sharedData)
     m_sharedData = sharedData;
     m_thumbJob   = 0L;
 
+    // --------------------------------------------------------
+
+    QVBoxLayout *listBoxContainerLayout = new QVBoxLayout;
+    m_ImagesFilesListBox                = new ImagesList(sharedData->interface, m_ImagesFilesListBoxContainer,
+                                                         ImagesList::NoControlButtons, KIconLoader::SizeMedium);
+    m_ImagesFilesListBox->listView()->header()->hide();
+    listBoxContainerLayout->addWidget(m_ImagesFilesListBox);
+    listBoxContainerLayout->setSpacing(0);
+    listBoxContainerLayout->setMargin(0);
+    m_ImagesFilesListBoxContainer->setLayout(listBoxContainerLayout);
+
+    // --------------------------------------------------------
+
     m_ImagesFilesButtonUp->setIcon(KIcon("arrow-up"));
     m_ImagesFilesButtonDown->setIcon(KIcon("arrow-down"));
     m_ImagesFilesButtonAdd->setIcon(KIcon("list-add"));
@@ -72,6 +90,13 @@ MainDialog::MainDialog( QWidget* parent, SharedData* sharedData)
     m_ImagesFilesButtonAdd->setText("");
     m_ImagesFilesButtonDelete->setText("");
 
+    // --------------------------------------------------------
+
+    m_previewLabel->setMinimumWidth(ICONSIZE);
+    m_previewLabel->setMinimumHeight(ICONSIZE);
+
+    // --------------------------------------------------------
+
     // Prepare a preview pixmap (KIPI logo) for no image selection
     QSvgRenderer svgRenderer( KStandardDirs::locate("data", "kipiplugin_advancedslideshow/KIPIicon.svg") );
     m_noPreviewPixmap = QPixmap(ICONSIZE, ICONSIZE);
@@ -87,28 +112,6 @@ MainDialog::~MainDialog()
 
 void MainDialog::readSettings()
 {
-    connect(m_sharedData->advancedPage, SIGNAL(useMillisecondsToggled()), this, SLOT(slotUseMillisecondsToggled()));
-    connect(m_printCommentsCheckBox, SIGNAL(toggled(bool)), this, SLOT(slotPrintCommentsToggled()));
-    connect(m_openglCheckBox, SIGNAL(toggled(bool)), this, SLOT(slotOpenGLToggled()));
-
-    connect(m_allFilesButton, SIGNAL(toggled(bool)), this, SLOT(slotSelection()));
-
-    connect(m_delaySpinBox, SIGNAL(valueChanged(int)), this, SLOT(slotDelayChanged()));
-    connect(m_effectsComboBox, SIGNAL(activated(int)), this,  SLOT(slotEffectChanged()));
-
-    connect( m_ImagesFilesListBox, SIGNAL( currentRowChanged( int ) ),
-             this, SLOT( slotImagesFilesSelected( int ) ) );
-    connect( m_ImagesFilesListBox, SIGNAL( addedDropItems(KUrl::List) ),
-             this, SLOT( slotAddDropItems(KUrl::List)));
-    connect( m_ImagesFilesButtonAdd, SIGNAL( clicked() ),
-             this, SLOT( slotImagesFilesButtonAdd() ) );
-    connect( m_ImagesFilesButtonDelete, SIGNAL( clicked() ),
-             this, SLOT( slotImagesFilesButtonDelete() ) );
-    connect( m_ImagesFilesButtonUp, SIGNAL( clicked() ),
-             this, SLOT( slotImagesFilesButtonUp() ) );
-    connect( m_ImagesFilesButtonDown, SIGNAL( clicked() ),
-             this, SLOT( slotImagesFilesButtonDown() ) );
-
     m_openglCheckBox->setChecked(m_sharedData->opengl);
     m_delaySpinBox->setValue(m_sharedData->delay);
     m_printNameCheckBox->setChecked(m_sharedData->printFileName);
@@ -133,24 +136,21 @@ void MainDialog::readSettings()
 
     m_selectedFilesButton->setEnabled( m_sharedData->showSelectedFilesOnly );
 
-
     m_delaySpinBox->setValue(m_sharedData->useMilliseconds ?
                              m_sharedData->delay : m_sharedData->delay / 1000 );
 
     slotUseMillisecondsToggled();
 
-    // ---------------------
-
-    if ( m_sharedData->showSelectedFilesOnly )
-        connect(m_selectedFilesButton, SIGNAL(toggled(bool)), this, SLOT(slotSelection()));
+    // --------------------------------------------------------
 
     slotOpenGLToggled();
-
     slotPrintCommentsToggled();
-
+    slotEffectChanged();
     slotSelection();
 
-    slotEffectChanged();
+    // --------------------------------------------------------
+
+    setupConnections();
 }
 
 void MainDialog::saveSettings()
@@ -221,28 +221,29 @@ void MainDialog::saveSettings()
     }
 }
 
-void MainDialog::ShowNumberImages( int Number )
+void MainDialog::showNumberImages()
 {
-    QTime TotalDuration (0, 0, 0);
+    int numberOfImages = m_ImagesFilesListBox->imageUrls().count();
+    QTime totalDuration (0, 0, 0);
 
-    int TransitionDuration = 2000;
+    int transitionDuration = 2000;
 
     if ( m_openglCheckBox->isChecked() )
-        TransitionDuration += 500;
+        transitionDuration += 500;
 
     if ( m_sharedData->useMilliseconds )
-        TotalDuration = TotalDuration.addMSecs(Number * m_delaySpinBox->text().toInt());
+        totalDuration = totalDuration.addMSecs(numberOfImages * m_delaySpinBox->text().toInt());
     else
-        TotalDuration = TotalDuration.addSecs(Number * m_delaySpinBox->text().toInt());
+        totalDuration = totalDuration.addSecs(numberOfImages * m_delaySpinBox->text().toInt());
 
-    TotalDuration = TotalDuration.addMSecs((Number - 1) * TransitionDuration);
+    totalDuration = totalDuration.addMSecs((numberOfImages - 1) * transitionDuration);
 
-    m_totalTime = TotalDuration;
+    m_totalTime = totalDuration;
 
     // Notify total time is changed
     emit totalTimeChanged(m_totalTime);
 
-    m_label6->setText(i18np("%1 image [%2]", "%1 images [%2]", Number, TotalDuration.toString()));
+    m_label6->setText(i18np("%1 image [%2]", "%1 images [%2]", numberOfImages, totalDuration.toString()));
 }
 
 void MainDialog::loadEffectNames()
@@ -307,92 +308,68 @@ void MainDialog::loadEffectNamesGL()
 
 bool MainDialog::updateUrlList()
 {
-    for (int i = 0 ; i < m_ImagesFilesListBox->count() ; ++i)
-    {
-        ImageItem *pitem = static_cast<ImageItem*>( m_ImagesFilesListBox->item(i) );
+    m_sharedData->urlList.clear();
 
-        if (!QFile::exists(pitem->path()))
+    QTreeWidgetItemIterator it(m_ImagesFilesListBox->listView());
+    while (*it)
+    {
+        ImagesListViewItem* item = dynamic_cast<ImagesListViewItem*>(*it);
+        if (!item)
+            continue;
+
+        QString url = item->url().path();
+
+        if (!QFile::exists(url))
         {
-            KMessageBox::error(this,
-                               i18n("Cannot access file %1. Please check the path is correct.", pitem->path()));
+            KMessageBox::error(this, i18n("Cannot access file %1. Please check the path is correct.", url));
             return false;
         }
 
-        m_sharedData->urlList.append(pitem->path());                              // Input images files.
+        m_sharedData->urlList.append(url);  // Input images files.
+        ++it;
     }
-
     return true;
 }
 
-// --- Slots
-
-void MainDialog::slotImagesFilesSelected( int row )
+void MainDialog::slotImagesFilesSelected(QTreeWidgetItem* item)
 {
-    QListWidgetItem* item = m_ImagesFilesListBox->item(row);
-
-    if ( !item || m_ImagesFilesListBox->count() == 0 )
+    if (!item || m_ImagesFilesListBox->imageUrls().isEmpty())
     {
         m_label7->setText("");
         m_previewLabel->setPixmap(m_noPreviewPixmap);
         return;
     }
 
-    ImageItem *pitem = static_cast<ImageItem*>( item );
+    ImagesListViewItem *pitem = static_cast<ImagesListViewItem*> (item);
 
-    if ( !pitem ) return;
+    if (!pitem)
+        return;
 
     KUrl url;
-
-    url.setPath(pitem->path());
+    url.setPath(pitem->url().path());
 
     connect(m_sharedData->interface, SIGNAL(gotThumbnail( const KUrl&, const QPixmap& )),
             this, SLOT(slotThumbnail(const KUrl&, const QPixmap&)));
+
     m_sharedData->interface->thumbnail(url, ICONSIZE);
 
-    int index = m_ImagesFilesListBox->row ( item );
-
-    m_label7->setText(i18nc("Image number %1", "Image #%1", QString::number(index + 1)));
+    QModelIndex index = m_ImagesFilesListBox->listView()->currentIndex();
+    if (index.isValid())
+    {
+        int rowindex = index.row();
+        m_label7->setText(i18nc("Image number %1", "Image #%1", QString::number(rowindex + 1)));
+    }
 }
 
 void MainDialog::addItems(const KUrl::List& fileList)
 {
-    if (fileList.isEmpty()) return;
+    if (fileList.isEmpty())
+        return;
+    KUrl::List files = fileList;
 
-    KUrl::List Files = fileList;
-
-    for ( KUrl::List::Iterator it = Files.begin() ; it != Files.end() ; ++it )
-    {
-        KUrl currentFile = *it;
-
-        QFileInfo fi(currentFile.path());
-        QString Temp = fi.path();
-        QString albumName = Temp.section('/', -1);
-
-        KIPI::ImageInfo info = m_sharedData->interface->info(currentFile);
-        QString comments = info.description();
-
-        ImageItem *item = new ImageItem( m_ImagesFilesListBox,
-                                         currentFile.path().section('/', -1 ),   // File name with extension.
-                                         comments,                               // Image comments.
-                                         currentFile.path().section('/', 0, -1), // Complete path with file name.
-                                         albumName,                              // Album name.
-                                         m_sharedData->interface
-                                       );
-
-        item->setName( currentFile.path().section('/', -1) );
-        m_ImagesFilesListBox->insertItem(m_ImagesFilesListBox->count() - 1, item);
-    }
-
-    ShowNumberImages( m_ImagesFilesListBox->count() );
-
-    m_ImagesFilesListBox->setCurrentItem(m_ImagesFilesListBox->item(m_ImagesFilesListBox->count() - 1)) ;
-    slotImagesFilesSelected(m_ImagesFilesListBox->currentRow());
-    m_ImagesFilesListBox->scrollToItem(m_ImagesFilesListBox->currentItem());
-}
-
-void MainDialog::slotAddDropItems(KUrl::List filesUrl)
-{
-    addItems(filesUrl);
+    m_ImagesFilesListBox->slotAddImages(files);
+    showNumberImages();
+    slotImagesFilesSelected(m_ImagesFilesListBox->listView()->currentItem());
 }
 
 void MainDialog::slotImagesFilesButtonAdd( void )
@@ -404,75 +381,48 @@ void MainDialog::slotImagesFilesButtonAdd( void )
     {
         addItems(urls);
     }
-
 }
 
 void MainDialog::slotImagesFilesButtonDelete( void )
 {
-    int Index = m_ImagesFilesListBox->currentRow();
-    ImageItem* pitem = static_cast<ImageItem*>(m_ImagesFilesListBox->takeItem(Index));
-    delete pitem;
+    ImagesListViewItem* item = dynamic_cast<ImagesListViewItem*>(m_ImagesFilesListBox->listView()->currentItem());
+    if (!item)
+        return;
 
-    slotImagesFilesSelected(m_ImagesFilesListBox->currentRow());
-    ShowNumberImages( m_ImagesFilesListBox->count() );
+    m_ImagesFilesListBox->removeItemByUrl(item->url());
+
+    showNumberImages();
+    slotImagesFilesSelected(m_ImagesFilesListBox->listView()->currentItem());
 }
 
 void MainDialog::slotImagesFilesButtonUp( void )
 {
-    int Cpt = 0;
-
-    for (int i = 0 ; i < m_ImagesFilesListBox->count() ; ++i)
-        if (m_ImagesFilesListBox->currentRow() == i)
-            ++Cpt;
-
-    if  (Cpt == 0)
+    QModelIndex curIndex   = m_ImagesFilesListBox->listView()->currentIndex();
+    if (!curIndex.isValid())
         return;
 
-    if  (Cpt > 1)
-    {
-        KMessageBox::error(this, i18n("You can only move image files up one at a time."));
-        return;
-    }
-
-    unsigned int Index = m_ImagesFilesListBox->currentRow();
-
-    if (Index == 0)
+    QModelIndex aboveIndex = m_ImagesFilesListBox->listView()->indexAbove(curIndex);
+    if (!aboveIndex.isValid())
         return;
 
-    ImageItem* pitem = static_cast<ImageItem*>(m_ImagesFilesListBox->takeItem(Index));
-
-    m_ImagesFilesListBox->insertItem(Index - 1, pitem);
-
-    m_ImagesFilesListBox->setCurrentItem(pitem);
+    QTreeWidgetItem* temp = m_ImagesFilesListBox->listView()->takeTopLevelItem(aboveIndex.row());
+    QModelIndex curTemp   = m_ImagesFilesListBox->listView()->currentIndex();
+    m_ImagesFilesListBox->listView()->insertTopLevelItem(curIndex.row(), temp);
 }
 
 void MainDialog::slotImagesFilesButtonDown( void )
 {
-    int Cpt = 0;
-
-    for (int i = 0 ; i < m_ImagesFilesListBox->count() ; ++i)
-        if (m_ImagesFilesListBox->currentRow() == i)
-            ++Cpt;
-
-    if (Cpt == 0)
+    QModelIndex curIndex   = m_ImagesFilesListBox->listView()->currentIndex();
+    if (!curIndex.isValid())
         return;
 
-    if (Cpt > 1)
-    {
-        KMessageBox::error(this, i18n("You can only move image files down one at a time."));
-        return;
-    }
-
-    int Index = m_ImagesFilesListBox->currentRow();
-
-    if (Index == m_ImagesFilesListBox->count())
+    QModelIndex belowIndex = m_ImagesFilesListBox->listView()->indexBelow(curIndex);
+    if (!belowIndex.isValid())
         return;
 
-    ImageItem* pitem = static_cast<ImageItem*>(m_ImagesFilesListBox->takeItem(Index));
-
-    m_ImagesFilesListBox->insertItem(Index + 1, pitem);
-
-    m_ImagesFilesListBox->setCurrentItem(pitem);
+    QTreeWidgetItem* temp = m_ImagesFilesListBox->listView()->takeTopLevelItem(belowIndex.row());
+    QModelIndex curTemp   = m_ImagesFilesListBox->listView()->currentIndex();
+    m_ImagesFilesListBox->listView()->insertTopLevelItem(curIndex.row(), temp);
 }
 
 void MainDialog::slotOpenGLToggled( void )
@@ -486,8 +436,7 @@ void MainDialog::slotOpenGLToggled( void )
         loadEffectNames();
     }
 
-    ShowNumberImages( m_ImagesFilesListBox->count() );
-
+    showNumberImages();
     slotEffectChanged();
 }
 
@@ -502,17 +451,15 @@ void MainDialog::slotEffectChanged( void )
                                            m_printCommentsCheckBox->isChecked());
 }
 
-void MainDialog::slotDelayChanged( void )
+void MainDialog::slotDelayChanged( int delay )
 {
-    ShowNumberImages( m_ImagesFilesListBox->count() );
+    m_sharedData->delay = m_sharedData->useMilliseconds ? delay : delay * 1000;
+    showNumberImages();
 }
 
 void MainDialog::slotUseMillisecondsToggled( void )
 {
-
-    int delayValue = m_delaySpinBox->value();
-
-    m_delaySpinBox->setValue(0);
+    int delay = m_sharedData->delay;
 
     if ( m_sharedData->useMilliseconds )
     {
@@ -520,18 +467,17 @@ void MainDialog::slotUseMillisecondsToggled( void )
 
         m_delaySpinBox->setRange(m_sharedData->delayMsMinValue, m_sharedData->delayMsMaxValue);
         m_delaySpinBox->setSingleStep(m_sharedData->delayMsLineStep);
-
-        m_delaySpinBox->setValue(delayValue*1000);
     }
     else
     {
         m_delayLabel->setText(i18n("Delay between images (s):"));
 
-        m_delaySpinBox->setRange(m_sharedData->delayMsMinValue / 100, m_sharedData->delayMsMaxValue / 10);
+        m_delaySpinBox->setRange(m_sharedData->delayMsMinValue / 100, m_sharedData->delayMsMaxValue / 1000  );
         m_delaySpinBox->setSingleStep(m_sharedData->delayMsLineStep / 100);
+        delay /= 1000;
 
-        m_delaySpinBox->setValue(delayValue / 1000);
     }
+    m_delaySpinBox->setValue(delay);
 }
 
 void MainDialog::slotSelection( void )
@@ -540,38 +486,32 @@ void MainDialog::slotSelection( void )
 
     if (m_selectedFilesButton->isChecked())
     {
-
         urlList = m_sharedData->interface->currentSelection().images();
+        m_ImagesFilesListBox->listView()->clear();
 
         m_ImagesFilesButtonAdd->setEnabled(false);
         m_ImagesFilesButtonDelete->setEnabled(false);
         m_ImagesFilesButtonUp->setEnabled(false);
         m_ImagesFilesButtonDown->setEnabled(false);
     }
-    else
-        if (m_allFilesButton->isChecked())
-        {
+    else if (m_allFilesButton->isChecked())
+    {
+        KUrl currentPath = m_sharedData->interface->currentAlbum().path();
+        QList<KIPI::ImageCollection> albumList;
+        albumList = m_sharedData->interface->allAlbums();
 
-            KUrl currentPath = m_sharedData->interface->currentAlbum().path();
-            Q3ValueList<KIPI::ImageCollection> albumList;
+        urlList = m_sharedData->interface->currentAlbum().images();
 
-            albumList = m_sharedData->interface->allAlbums();
-            Q3ValueList<KIPI::ImageCollection>::iterator it;
+        QList<KIPI::ImageCollection>::iterator it;
+        for (it = albumList.begin(); it != albumList.end(); ++it)
+            if (currentPath.isParentOf((*it).path()) && !((*it).path() == currentPath))
+                urlList += (*it).images();
 
-            urlList = m_sharedData->interface->currentAlbum().images();
-
-            for ( it = albumList.begin(); it != albumList.end(); ++it )
-                if (currentPath.isParentOf((*it).path()) && !((*it).path() == currentPath))
-                    urlList += (*it).images();
-
-            m_ImagesFilesButtonAdd->setEnabled(false);
-
-            m_ImagesFilesButtonDelete->setEnabled(false);
-
-            m_ImagesFilesButtonUp->setEnabled(false);
-
-            m_ImagesFilesButtonDown->setEnabled(false);
-        }
+        m_ImagesFilesButtonAdd->setEnabled(false);
+        m_ImagesFilesButtonDelete->setEnabled(false);
+        m_ImagesFilesButtonUp->setEnabled(false);
+        m_ImagesFilesButtonDown->setEnabled(false);
+    }
 
     if ( m_customButton->isChecked() )    // Custom selected
     {
@@ -584,15 +524,14 @@ void MainDialog::slotSelection( void )
     {
         if (!urlList.isEmpty())
         {
-            m_ImagesFilesListBox->clear();
             addItems(urlList);
         }
     }
 }
 
-void MainDialog::SlotPortfolioDurationChanged ( int )
+void MainDialog::slotPortfolioDurationChanged ( int )
 {
-    ShowNumberImages( m_ImagesFilesListBox->count() );
+    showNumberImages();
     emit totalTimeChanged( m_totalTime );
 }
 
@@ -612,4 +551,46 @@ void MainDialog::slotPrintCommentsToggled( void )
     m_sharedData->page_caption->setEnabled(m_printCommentsCheckBox->isChecked());
 }
 
+void MainDialog::setupConnections()
+{
+    connect(m_sharedData->advancedPage, SIGNAL(useMillisecondsToggled()), this,
+            SLOT(slotUseMillisecondsToggled()));
+
+    connect(m_printCommentsCheckBox, SIGNAL(toggled(bool)),
+            this, SLOT(slotPrintCommentsToggled()));
+
+    connect(m_openglCheckBox, SIGNAL(toggled(bool)),
+            this, SLOT(slotOpenGLToggled()));
+
+    connect(m_allFilesButton, SIGNAL(toggled(bool)),
+            this, SLOT(slotSelection()));
+
+    connect(m_delaySpinBox, SIGNAL(valueChanged(int)),
+            this, SLOT(slotDelayChanged(int)));
+
+    connect(m_effectsComboBox, SIGNAL(activated(int)),
+            this, SLOT(slotEffectChanged()));
+
+    connect(m_ImagesFilesListBox, SIGNAL( signalItemClicked(QTreeWidgetItem*) ),
+            this, SLOT( slotImagesFilesSelected(QTreeWidgetItem*) ));
+
+    connect(m_ImagesFilesButtonAdd, SIGNAL( clicked() ),
+            this, SLOT( slotImagesFilesButtonAdd() ));
+
+    connect(m_ImagesFilesButtonDelete, SIGNAL( clicked() ),
+            this, SLOT( slotImagesFilesButtonDelete() ));
+
+    connect(m_ImagesFilesButtonUp, SIGNAL( clicked() ),
+            this, SLOT( slotImagesFilesButtonUp() ));
+
+    connect(m_ImagesFilesButtonDown, SIGNAL( clicked() ),
+            this, SLOT( slotImagesFilesButtonDown() ));
+
+    if (m_sharedData->showSelectedFilesOnly)
+    {
+        connect(m_selectedFilesButton, SIGNAL(toggled(bool)),
+                this, SLOT(slotSelection()));
+    }
+}
+
 }  // namespace KIPIAdvancedSlideshowPlugin
