@@ -6,7 +6,8 @@
  * Date        : 2008-09-09
  * Description : a kipi plugin to slide images.
  *
- * Copyright (C) 2008 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
+ * Copyright (C) 2008-2009 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
+ * Copyright (C) 2009 by Andi Clemens <andi dot clemens at gmx dot net>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -37,6 +38,13 @@
 #include "common.h"
 #include "ui_maindialog.h"
 
+class QTreeWidgetItem;
+
+namespace KIPIPlugins
+{
+class ImagesList;
+}
+
 namespace KIPIAdvancedSlideshowPlugin
 {
 
@@ -51,23 +59,22 @@ public:
     MainDialog(QWidget* parent, SharedData* sharedData);
     ~MainDialog();
 
-    void  readSettings();
-    void  saveSettings();
-    bool  updateUrlList();
+    void readSettings();
+    void saveSettings();
+    bool updateUrlList();
 
 private Q_SLOTS:
 
     void slotOpenGLToggled( void );
     void slotEffectChanged( void );
-    void slotDelayChanged( void );
+    void slotDelayChanged( int );
     void slotPrintCommentsToggled( void );
     void slotSelection( void );
     void slotUseMillisecondsToggled( void );
     void slotThumbnail(const KUrl&, const QPixmap&);
 
-    void SlotPortfolioDurationChanged ( int );
-    void slotImagesFilesSelected( int );
-    void slotAddDropItems(KUrl::List filesUrl);
+    void slotPortfolioDurationChanged ( int );
+    void slotImagesFilesSelected(QTreeWidgetItem* item);
     void slotImagesFilesButtonAdd( void );
     void slotImagesFilesButtonDelete( void );
     void slotImagesFilesButtonUp( void );
@@ -79,18 +86,20 @@ Q_SIGNALS :
 
 private:
 
+    void setupConnections();
     void loadEffectNames();
     void loadEffectNamesGL();
 
-    void ShowNumberImages( int Number );
+    void showNumberImages();
     void addItems(const KUrl::List& fileList);
 
 private:
 
-    SharedData*      m_sharedData;
-    KIO::PreviewJob* m_thumbJob;
-    QTime            m_totalTime;
-    QPixmap          m_noPreviewPixmap;
+    SharedData*              m_sharedData;
+    KIO::PreviewJob*         m_thumbJob;
+    QTime                    m_totalTime;
+    QPixmap                  m_noPreviewPixmap;
+    KIPIPlugins::ImagesList* m_ImagesFilesListBox;
 };
 
 } // namespace KIPIAdvancedSlideshowPlugin
