@@ -6,7 +6,8 @@
  * Date        : 2003-01-31
  * Description : a kipi plugin to slide images.
  *
- * Copyright (C) 2006-2008 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
+ * Copyright (C) 2006-2009 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
+ * Copyright (C) 2009 by Andi Clemens <andi dot clemens at gmx dot net>
  * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
  *
  * This program is free software; you can redistribute it
@@ -31,7 +32,7 @@
 
 // Qt includes
 
-#include <Q3ValueList>
+#include <QList>
 #include <QPair>
 #include <QStringList>
 
@@ -64,25 +65,22 @@ using namespace KIPIAdvancedSlideshowPlugin;
 K_PLUGIN_FACTORY( AdvancedSlideshowFactory, registerPlugin<Plugin_AdvancedSlideshow>(); )
 K_EXPORT_PLUGIN ( AdvancedSlideshowFactory("kipiplugin_advancedslideshow") )
 
-Plugin_AdvancedSlideshow::Plugin_AdvancedSlideshow(QObject *parent, const QVariantList &args)
-                : KIPI::Plugin( AdvancedSlideshowFactory::componentData(), parent, "AdvancedSlideshow")
+Plugin_AdvancedSlideshow::Plugin_AdvancedSlideshow(QObject *parent, const QVariantList &/*args*/)
+                        : KIPI::Plugin(AdvancedSlideshowFactory::componentData(),
+                                       parent, "AdvancedSlideshow")
 {
-    // Useless: to please the compiler
-    QVariantList argsList = args;
-
-    kDebug( 51001 ) << "Plugin_AdvancedSlideshow plugin loaded" << endl;
-
+    kDebug(51001) << "Plugin_AdvancedSlideshow plugin loaded" ;
     m_sharedData = 0;
 }
 
-void Plugin_AdvancedSlideshow::setup( QWidget* widget )
+void Plugin_AdvancedSlideshow::setup(QWidget* widget)
 {
-    KIPI::Plugin::setup( widget );
+    KIPI::Plugin::setup(widget);
 
     m_actionSlideShow = actionCollection()->addAction("advancedslideshow");
     m_actionSlideShow->setText(i18n("Advanced Slideshow..."));
     m_actionSlideShow->setIcon(KIcon("slideshow"));
-    m_actionSlideShow->setShortcut(Qt::ALT+Qt::SHIFT+Qt::Key_F9);
+    m_actionSlideShow->setShortcut(Qt::ALT + Qt::SHIFT + Qt::Key_F9);
     m_actionSlideShow->setEnabled(false);
 
     connect(m_actionSlideShow, SIGNAL(triggered(bool)),
@@ -90,30 +88,34 @@ void Plugin_AdvancedSlideshow::setup( QWidget* widget )
 
     addAction(m_actionSlideShow);
 
-    m_interface = dynamic_cast< KIPI::Interface* >( parent() );
+    m_interface = dynamic_cast<KIPI::Interface*> (parent());
 
-    if ( !m_interface )
+    if (!m_interface)
     {
-        kError( 51000 ) << "Kipi m_interface is null!" << endl;
+        kError(51000) << "Kipi m_interface is null!";
         return;
     }
 
-    m_urlList = new KUrl::List();
+    m_urlList = KUrl::List();
 
     connect(m_interface, SIGNAL( currentAlbumChanged( bool )),
             this, SLOT( slotAlbumChanged( bool )));
+
+    if (m_interface->currentAlbum().isValid())
+    {
+        slotAlbumChanged(true);
+    }
 }
 
 Plugin_AdvancedSlideshow::~Plugin_AdvancedSlideshow()
 {
-    delete m_urlList;
 }
 
 void Plugin_AdvancedSlideshow::slotActivate()
 {
-    if ( !m_interface )
+    if (!m_interface)
     {
-        kError( 51000 ) << "Kipi m_interface is null!" << endl;
+        kError(51000) << "Kipi m_interface is null!";
         return;
     }
 
@@ -125,12 +127,12 @@ void Plugin_AdvancedSlideshow::slotActivate()
     m_sharedData->urlList               = m_urlList;
     KIPI::ImageCollection currSel       = m_interface->currentSelection();
 
-    if ( !currSel.isValid() || currSel.images().isEmpty() )
+    if (!currSel.isValid() || currSel.images().count() <= 1)
     {
         m_sharedData->showSelectedFilesOnly = false;
     }
 
-    SlideShowConfig *slideShowConfig = new SlideShowConfig( kapp->activeWindow(), m_sharedData );
+    SlideShowConfig *slideShowConfig = new SlideShowConfig(kapp->activeWindow(), m_sharedData);
 
     connect(slideShowConfig, SIGNAL(buttonStartClicked()),
             this, SLOT(slotSlideShow()));
@@ -142,25 +144,25 @@ void Plugin_AdvancedSlideshow::slotAlbumChanged(bool anyAlbum)
 {
     if (!anyAlbum)
     {
-        m_actionSlideShow->setEnabled( false );
+        m_actionSlideShow->setEnabled(false);
         return;
     }
 
-    KIPI::Interface* m_interface = dynamic_cast<KIPI::Interface*>( parent() );
+    KIPI::Interface* m_interface = dynamic_cast<KIPI::Interface*> (parent());
 
-    if ( !m_interface )
+    if (!m_interface)
     {
-        kError( 51000 ) << "Kipi m_interface is null!";
-        m_actionSlideShow->setEnabled( false );
+        kError(51000) << "Kipi m_interface is null!";
+        m_actionSlideShow->setEnabled(false);
         return;
     }
 
     KIPI::ImageCollection currAlbum = m_interface->currentAlbum();
 
-    if ( !currAlbum.isValid() )
+    if (!currAlbum.isValid())
     {
-        kError( 51000 ) << "Current image collection is not valid." << endl;
-        m_actionSlideShow->setEnabled( false );
+        kError(51000) << "Current image collection is not valid.";
+        m_actionSlideShow->setEnabled(false);
         return;
     }
 
@@ -169,46 +171,43 @@ void Plugin_AdvancedSlideshow::slotAlbumChanged(bool anyAlbum)
 
 void Plugin_AdvancedSlideshow::slotSlideShow()
 {
-    if ( !m_interface )
+    if (!m_interface)
     {
-        kError( 51000 ) << "Kipi m_interface is null!" << endl;
+        kError(51000) << "Kipi m_interface is null!";
         return;
     }
 
     KConfig config("kipirc");
-
-    bool    opengl;
-    bool    shuffle;
-    bool    wantKB;
     KConfigGroup grp = config.group("Advanced Slideshow Settings");
-    opengl           = grp.readEntry("OpenGL", false);
-    shuffle          = grp.readEntry("Shuffle", false);
-    wantKB           = grp.readEntry("Effect Name (OpenGL)") == QString("Ken Burns");
+    bool opengl      = grp.readEntry("OpenGL",  false);
+    bool shuffle     = grp.readEntry("Shuffle", false);
+    bool wantKB      = grp.readEntry("Effect Name (OpenGL)") == QString("Ken Burns");
 
-    if ( m_urlList->isEmpty() )
+    m_urlList = m_sharedData->urlList;
+    if (m_urlList.isEmpty())
     {
         KMessageBox::sorry(kapp->activeWindow(), i18n("There are no images to show."));
         return;
     }
 
-    typedef QPair<QString, int> FileAnglePair;
-
-    typedef Q3ValueList<FileAnglePair > FileList;
-    FileList fileList;
+    typedef QPair<QString, int>  FileAnglePair;
+    typedef QList<FileAnglePair> FileList;
+    FileList    fileList;
     QStringList commentsList;
 
-    for ( KUrl::List::ConstIterator urlIt = m_urlList->constBegin(); urlIt != m_urlList->constEnd(); ++urlIt )
+    for (KUrl::List::ConstIterator urlIt = m_urlList.constBegin(); urlIt != m_urlList.constEnd(); ++urlIt)
     {
-        KIPI::ImageInfo info = m_interface->info( *urlIt );
-        fileList.append( FileAnglePair((*urlIt).path(), info.angle()) );
-        commentsList.append(info.description());
+        fileList.append(FileAnglePair((*urlIt).path(), 0));
+        commentsList.append(QString());
+//        KIPI::ImageInfo info = m_interface->info( *urlIt );
+//        fileList.append( FileAnglePair((*urlIt).path(), info.angle()) );
+//        commentsList.append(info.description());
     }
 
-    m_urlList->clear();
+    m_urlList.clear();
 
     if (shuffle)
     {
-
         struct timeval tv;
         gettimeofday(&tv, 0);
         srand(tv.tv_sec);
@@ -260,9 +259,9 @@ void Plugin_AdvancedSlideshow::slotSlideShow()
     }
 }
 
-KIPI::Category Plugin_AdvancedSlideshow::category( KAction* action ) const
+KIPI::Category Plugin_AdvancedSlideshow::category(KAction* action) const
 {
-    if ( action == m_actionSlideShow )
+    if (action == m_actionSlideShow)
         return KIPI::ToolsPlugin;
 
     kWarning( 51000 ) << "Unrecognized action for plugin category identification";
