@@ -6,7 +6,8 @@
  * Date        : 2003-02-16
  * Description : a kipi plugin to slide images.
  *
- * Copyright (C) 2006-2008 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
+ * Copyright (C) 2006-2009 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
+ * Copyright (C) 2009 by Andi Clemens <andi dot clemens at gmx dot net>
  * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
  *
  * This program is free software; you can redistribute it
@@ -26,48 +27,46 @@
 
 // C++ includes
 
-#include <cstdlib>
 #include <cassert>
 #include <cmath>
+#include <cstdlib>
 #include <ctime>
 
 // Qt includes
 
-#include <Q3PointArray>
-#include <QTimer>
-#include <QPainter>
-#include <QPixmap>
-#include <QImage>
-#include <QApplication>
-#include <QDesktopWidget>
-#include <QEvent>
 #include <QCursor>
 #include <QFont>
-#include <QMatrix>
-#include <QTextCodec>
 #include <QKeyEvent>
+#include <QMatrix>
 #include <QMouseEvent>
-#include <QWheelEvent>
+#include <QPainter>
 #include <QPainterPath>
+#include <QPixmap>
 #include <QPolygon>
 #include <QSvgRenderer>
+#include <QTimer>
+#include <QWheelEvent>
 
 // KDE includes
 
-#include <klocale.h>
-#include <kdeversion.h>
 #include <kglobalsettings.h>
-#include <kdebug.h>
-#include <kurl.h>
+#include <klocale.h>
 #include <kstandarddirs.h>
-#include <KConfigGroup>
+
+// Local includes
+
+#include "common.h"
+#include "slideplaybackwidget.h"
+#include "slideshowloader.h"
 
 namespace KIPIAdvancedSlideshowPlugin
 {
 
 SlideShow::SlideShow( const FileList& fileList, const QStringList& commentsList, SharedData* sharedData )
-         : QWidget( 0, Qt::WStyle_StaysOnTop | Qt::WType_Popup | Qt::WX11BypassWM | Qt::WDestructiveClose )
+         : QWidget( 0, Qt::WindowStaysOnTopHint | Qt::Popup | Qt::X11BypassWindowManagerHint )
 {
+    setAttribute(Qt::WA_DeleteOnClose);
+
     m_sharedData   = sharedData;
     QRect deskRect = KGlobalSettings::desktopGeometry( this );
     m_deskX        = deskRect.x();
@@ -80,27 +79,33 @@ SlideShow::SlideShow( const FileList& fileList, const QStringList& commentsList,
 
     m_slidePlaybackWidget = new SlidePlaybackWidget( this );
     m_slidePlaybackWidget->hide();
+    m_slidePlaybackWidget->move(m_deskWidth - m_slidePlaybackWidget->width(), m_deskY);
 
     if ( !m_sharedData->loop )
     {
         m_slidePlaybackWidget->setEnabledPrev( false );
     }
 
-    connect( m_slidePlaybackWidget, SIGNAL( signalPause() ),
+    // -- playback widget -------------------------------
 
-             this, SLOT( slotPause() ) );
+    m_playbackWidget = new PlaybackWidget(this, m_sharedData->soundtrackUrls, m_sharedData);
+    m_playbackWidget->hide();
+    m_playbackWidget->move(m_deskX, m_deskY);
 
-    connect( m_slidePlaybackWidget, SIGNAL( signalPlay() ),
-             this, SLOT( slotPlay() ) );
+    connect(m_slidePlaybackWidget, SIGNAL( signalPause() ),
+            this, SLOT( slotPause() ));
 
-    connect( m_slidePlaybackWidget, SIGNAL( signalNext() ),
-             this, SLOT( slotNext() ) );
+    connect(m_slidePlaybackWidget, SIGNAL( signalPlay() ),
+            this, SLOT( slotPlay() ));
 
-    connect( m_slidePlaybackWidget, SIGNAL( signalPrev() ),
-             this, SLOT( slotPrev() ) );
+    connect(m_slidePlaybackWidget, SIGNAL( signalNext() ),
+            this, SLOT( slotNext() ));
 
-    connect( m_slidePlaybackWidget, SIGNAL( signalClose() ),
-             this, SLOT( slotClose() ) );
+    connect(m_slidePlaybackWidget, SIGNAL( signalPrev() ),
+            this, SLOT( slotPrev() ));
+
+    connect(m_slidePlaybackWidget, SIGNAL( signalClose() ),
+            this, SLOT( slotClose() ));
 
     // ---------------------------------------------------------------
 
@@ -113,43 +118,42 @@ SlideShow::SlideShow( const FileList& fileList, const QStringList& commentsList,
     m_startPainter  = false;
 
     m_timer = new QTimer(this);
-    connect( m_timer, SIGNAL( timeout() ),
-             this, SLOT( slotTimeOut() ) );
+    connect(m_timer, SIGNAL(timeout()),
+            this, SLOT(slotTimeOut()));
 
-    m_pa = Q3PointArray( 4 );
+    m_pa     = QPolygon( 4 );
     m_buffer = QPixmap( size() );
     m_buffer.fill( Qt::black );
 
-    m_fileList          = fileList;
-    m_commentsList      = commentsList;
+    m_fileList     = fileList;
+    m_commentsList = commentsList;
 
     if ( m_sharedData->enableCache )
         m_cacheSize  = m_sharedData->cacheSize;
     else
         m_cacheSize = 1;
 
-    m_imageLoader = new SlideShowLoader( m_fileList, m_cacheSize, width(), height(), m_fileIndex );
+    m_imageLoader = new SlideShowLoader( m_fileList, m_cacheSize, width(), height(), m_sharedData, m_fileIndex);
 
     // --------------------------------------------------
 
     registerEffects();
 
-    if ( m_sharedData->effectName  == "Random" )
+    if (m_sharedData->effectName == "Random")
         m_effect = getRandomEffect();
     else
     {
         m_effectName = m_sharedData->effectName;
-        m_effect = Effects[m_sharedData->effectName];
+        m_effect     = Effects[m_sharedData->effectName];
 
-        if ( !m_effect )
+        if (!m_effect)
         {
-            m_effect = Effects["None"];
+            m_effect     = Effects["None"];
             m_effectName = "None";
         }
     }
 
     m_timer->setSingleShot( true );
-
     m_timer->start( 10 );
 
     // -- hide cursor when not moved --------------------
@@ -178,9 +182,6 @@ SlideShow::~SlideShow()
 
 void SlideShow::readSettings()
 {
-
-
-
 }
 
 void SlideShow::registerEffects()
@@ -412,7 +413,9 @@ void SlideShow::printComments()
 {
     if ( m_currImage.isNull() ) return;
 
-    QString comments = m_commentsList[m_fileIndex];
+//    QString comments = m_commentsList[m_fileIndex];
+    KIPI::ImageInfo info = m_sharedData->interface->info(m_imageLoader->currPath());
+    QString comments = info.description();
 
     int yPos = 30; // Text Y coordinate
 
@@ -537,12 +540,13 @@ void SlideShow::showEndOfShow()
     m_slidePlaybackWidget->setEnabledPrev( false );
 }
 
-void SlideShow::keyPressEvent( QKeyEvent *event )
+void SlideShow::keyPressEvent(QKeyEvent *event)
 {
-    if ( !event )
+    if (!event)
         return;
 
-    m_slidePlaybackWidget->keyPressEvent( event );
+    m_playbackWidget->keyPressEvent(event);
+    m_slidePlaybackWidget->keyPressEvent(event);
 }
 
 void SlideShow::mousePressEvent( QMouseEvent *e )
@@ -570,7 +574,7 @@ void SlideShow::mouseMoveEvent( QMouseEvent *e )
     m_mouseMoveTimer->setSingleShot( true );
     m_mouseMoveTimer->start( 1000 );
 
-    if ( !m_slidePlaybackWidget->canHide() )
+    if (!m_slidePlaybackWidget->canHide() || !m_playbackWidget->canHide())
         return;
 
     QPoint pos( e->pos() );
@@ -578,38 +582,44 @@ void SlideShow::mouseMoveEvent( QMouseEvent *e )
     if (( pos.y() > ( m_deskY + 20 ) ) &&
             ( pos.y() < ( m_deskY + m_deskHeight - 20 - 1 ) ) )
     {
-        if ( m_slidePlaybackWidget->isHidden() )
+        if (!m_slidePlaybackWidget->canHide() || !m_playbackWidget->canHide())
+        {
             return;
+        }
         else
+        {
             m_slidePlaybackWidget->hide();
+            m_playbackWidget->hide();
+        }
+
 
         return;
     }
 
-    int w = m_slidePlaybackWidget->width();
-
-    int h = m_slidePlaybackWidget->height();
-
-    if ( pos.y() < ( m_deskY + 20 ) )
-    {
-        if ( pos.x() <= ( m_deskX + m_deskWidth / 2 ) )
-            // position top left
-            m_slidePlaybackWidget->move( m_deskX, m_deskY );
-        else
-            // position top right
-            m_slidePlaybackWidget->move( m_deskX + m_deskWidth - w - 1, m_deskY );
-    }
-    else
-    {
-        if ( pos.x() <= ( m_deskX + m_deskWidth / 2 ) )
-            // position bot left
-            m_slidePlaybackWidget->move( m_deskX, m_deskY + m_deskHeight - h - 1 );
-        else
-            // position bot right
-            m_slidePlaybackWidget->move( m_deskX + m_deskWidth - w - 1, m_deskY + m_deskHeight - h - 1 );
-    }
+//    int w = m_slidePlaybackWidget->width();
+//    int h = m_slidePlaybackWidget->height();
+//
+//    if ( pos.y() < ( m_deskY + 20 ) )
+//    {
+//        if ( pos.x() <= ( m_deskX + m_deskWidth / 2 ) )
+//            // position top left
+//            m_slidePlaybackWidget->move( m_deskX, m_deskY );
+//        else
+//            // position top right
+//            m_slidePlaybackWidget->move( m_deskX + m_deskWidth - w - 1, m_deskY );
+//    }
+//    else
+//    {
+//        if ( pos.x() <= ( m_deskX + m_deskWidth / 2 ) )
+//            // position bot left
+//            m_slidePlaybackWidget->move( m_deskX, m_deskY + m_deskHeight - h - 1 );
+//        else
+//            // position bot right
+//            m_slidePlaybackWidget->move( m_deskX + m_deskWidth - w - 1, m_deskY + m_deskHeight - h - 1 );
+//    }
 
     m_slidePlaybackWidget->show();
+    m_playbackWidget->show();
 }
 
 void SlideShow::wheelEvent( QWheelEvent *e )
