@@ -6,7 +6,8 @@
  * Date        : 2003-02-16
  * Description : a kipi plugin to slide images.
  *
- * Copyright (C) 2006-2008 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
+ * Copyright (C) 2006-2009 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
+ * Copyright (C) 2009 by Andi Clemens <andi dot clemens at gmx dot net>
  * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
  *
  * This program is free software; you can redistribute it
@@ -26,51 +27,34 @@
 
 // Qt includes
 
-#include <Q3PointArray>
-#include <Q3ValueList>
-#include <QFont>
-#include <QKeyEvent>
+#include <QList>
 #include <QMap>
-#include <QMouseEvent>
-#include <QPainter>
 #include <QPair>
 #include <QPixmap>
+#include <QPolygon>
 #include <QString>
 #include <QStringList>
-#include <QWheelEvent>
 #include <QWidget>
 
-// KDE includes
-
-#include <kconfig.h>
-#include <kurl.h>
-
-// LibKIPI includes
-
-#include <libkipi/imagecollection.h>
-#include <libkipi/interface.h>
-
-// Local includes
-
-#include "slideshowloader.h"
-#include "slideplaybackwidget.h"
-#include "common.h"
-
+class QKeyEvent;
+class QMouseEvent;
+class QPaintEvent;
 class QTimer;
+class QWheelEvent;
 
-typedef QPair<QString, int> FileAnglePair;
-typedef Q3ValueList<FileAnglePair > FileList;
+typedef QPair<QString, int>  FileAnglePair;
+typedef QList<FileAnglePair> FileList;
 
 namespace KIPIAdvancedSlideshowPlugin
 {
 
+class SlideShowLoader;
 class SlidePlaybackWidget;
-
-class SlideShow;
+class SharedData;
+class PlaybackWidget;
 
 class SlideShow : public QWidget
 {
-
     Q_OBJECT
 
     typedef int (SlideShow::*EffectMethod)(bool);
@@ -82,51 +66,51 @@ public:
 
     void registerEffects();
 
-    static QStringList effectNames();
+    static QStringList            effectNames();
     static QMap<QString, QString> effectNamesI18N();
 
 
 protected:
 
-    void mousePressEvent(QMouseEvent *event);
-    void mouseMoveEvent(QMouseEvent *);
-    void wheelEvent(QWheelEvent *);
-    void keyPressEvent(QKeyEvent *event);
+    void    mousePressEvent(QMouseEvent *event);
+    void    mouseMoveEvent(QMouseEvent *);
+    void    wheelEvent(QWheelEvent *);
+    void    keyPressEvent(QKeyEvent *event);
 
-    int effectNone(bool);
-    int effectChessboard(bool doInit);
-    int effectMeltdown(bool doInit);
-    int effectSweep(bool doInit);
-    int effectMosaic(bool doInit);
-    int effectCubism(bool doInit);
-    int effectRandom(bool doInit);
-    int effectGrowing(bool doInit);
-    int effectHorizLines(bool doInit);
-    int effectVertLines(bool doInit);
-    int effectMultiCircleOut(bool doInit);
-    int effectSpiralIn(bool doInit);
-    int effectCircleOut(bool doInit);
-    int effectBlobs(bool doInit);
+    int     effectNone(bool);
+    int     effectChessboard(bool doInit);
+    int     effectMeltdown(bool doInit);
+    int     effectSweep(bool doInit);
+    int     effectMosaic(bool doInit);
+    int     effectCubism(bool doInit);
+    int     effectRandom(bool doInit);
+    int     effectGrowing(bool doInit);
+    int     effectHorizLines(bool doInit);
+    int     effectVertLines(bool doInit);
+    int     effectMultiCircleOut(bool doInit);
+    int     effectSpiralIn(bool doInit);
+    int     effectCircleOut(bool doInit);
+    int     effectBlobs(bool doInit);
 
-    void paintEvent(QPaintEvent*);
-    void startPainter();
+    void    paintEvent(QPaintEvent*);
+    void    startPainter();
 
-    bool            m_simplyShow;
-    bool            m_startPainter;
-    int             m_px, m_py, m_psx, m_psy, m_psw, m_psh;
-    bool            m_endOfShow;
-    QPixmap         m_buffer;
+    bool    m_simplyShow;
+    bool    m_startPainter;
+    int     m_px, m_py, m_psx, m_psy, m_psw, m_psh;
+    bool    m_endOfShow;
+    QPixmap m_buffer;
 
 private Q_SLOTS:
 
-    void slotTimeOut();
-    void slotMouseMoveTimeOut();
+    void    slotTimeOut();
+    void    slotMouseMoveTimeOut();
 
-    void slotPause();
-    void slotPlay();
-    void slotPrev();
-    void slotNext();
-    void slotClose();
+    void    slotPause();
+    void    slotPlay();
+    void    slotPrev();
+    void    slotNext();
+    void    slotClose();
 
 private:
 
@@ -136,11 +120,11 @@ private:
     void         printFilename();
     void         printComments();
     void         printProgress();
-    EffectMethod getRandomEffect();
     void         showEndOfShow();
-
     void         readSettings();
 
+    EffectMethod getRandomEffect();
+
 private:
 
     SharedData*  m_sharedData;
@@ -152,6 +136,7 @@ private:
     QMap<QString, EffectMethod> Effects;
 
     SlideShowLoader*            m_imageLoader;
+    PlaybackWidget*             m_playbackWidget;
     QPixmap                     m_currImage;
 
     FileList                    m_fileList;
@@ -173,8 +158,8 @@ private:
     bool                        m_pdone;
     bool**                      m_pixelMatrix;
 
-    //static 
-    Q3PointArray                 m_pa;
+    //static
+    QPolygon                    m_pa;
 
     SlidePlaybackWidget*        m_slidePlaybackWidget;
     QTimer*                     m_mouseMoveTimer;
@@ -183,7 +168,6 @@ private:
     int                         m_deskY;
     int                         m_deskWidth;
     int                         m_deskHeight;
-
 };
 
 }  // namespace KIPIAdvancedSlideshowPlugin
