@@ -4,8 +4,9 @@
  * Date  : 2004-01-19
  * Description :
  *
- * Copyright 2004 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
- * Copyright 2006-2008 by Valerio Fuoglio <valerio.fuoglio@gmail.com>
+ * Copyright (C) 2004 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2006-2009 by Valerio Fuoglio <valerio.fuoglio@gmail.com>
+ * Copyright (C) 2009 by Andi Clemens <andi dot clemens at gmx dot net>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -30,7 +31,7 @@
 
 // Qt includes
 
-#include <Q3ValueList>
+#include <QList>
 #include <QTimer>
 #include <QPixmap>
 #include <QApplication>
@@ -61,16 +62,16 @@
 namespace KIPIAdvancedSlideshowPlugin
 {
 
-SlideShowGL::SlideShowGL(const Q3ValueList<QPair<QString, int> >& fileList,
+SlideShowGL::SlideShowGL(const QList<QPair<QString, int> >& fileList,
                          const QStringList& commentsList, SharedData* sharedData)
-        : QGLWidget(0, 0, Qt::WStyle_StaysOnTop | Qt::WType_Popup |
-                    Qt::WX11BypassWM | Qt::WDestructiveClose)
+           : QGLWidget(0, 0, Qt::WindowStaysOnTopHint | Qt::Popup | Qt::X11BypassWindowManagerHint)
 {
+    setAttribute(Qt::WA_DeleteOnClose);
     QRect deskRect = KGlobalSettings::desktopGeometry(this);
-    m_deskX      = deskRect.x();
-    m_deskY      = deskRect.y();
-    m_deskWidth  = deskRect.width();
-    m_deskHeight = deskRect.height();
+    m_deskX        = deskRect.x();
+    m_deskY        = deskRect.y();
+    m_deskWidth    = deskRect.width();
+    m_deskHeight   = deskRect.height();
 
     move(m_deskX, m_deskY);
     resize(m_deskWidth, m_deskHeight);
@@ -86,16 +87,19 @@ SlideShowGL::SlideShowGL(const Q3ValueList<QPair<QString, int> >& fileList,
     }
 
     connect(m_slidePlaybackWidget, SIGNAL(signalPause()),
+            this, SLOT(slotPause()));
 
-            SLOT(slotPause()));
     connect(m_slidePlaybackWidget, SIGNAL(signalPlay()),
-            SLOT(slotPlay()));
+            this, SLOT(slotPlay()));
+
     connect(m_slidePlaybackWidget, SIGNAL(signalNext()),
-            SLOT(slotNext()));
+            this, SLOT(slotNext()));
+
     connect(m_slidePlaybackWidget, SIGNAL(signalPrev()),
-            SLOT(slotPrev()));
+            this, SLOT(slotPrev()));
+
     connect(m_slidePlaybackWidget, SIGNAL(signalClose()),
-            SLOT(slotClose()));
+            this, SLOT(slotClose()));
 
     m_playbackWidget = new PlaybackWidget(this, m_sharedData->soundtrackUrls, m_sharedData);
     m_playbackWidget->hide();
@@ -117,24 +121,21 @@ SlideShowGL::SlideShowGL(const Q3ValueList<QPair<QString, int> >& fileList,
 
     // --------------------------------------------------
 
-    m_fileList       = fileList;
-    m_commentsList   = commentsList;
-
-    m_cacheSize = m_sharedData->enableCache ? m_sharedData->cacheSize : 1;
+    m_fileList      = fileList;
+    m_commentsList  = commentsList;
+    m_cacheSize     = m_sharedData->enableCache ? m_sharedData->cacheSize : 1;
 
     // ------------------------------------------------------------------
 
-    m_fileIndex  = 0;
-
-    m_texture[0] = 0;
-    m_texture[1] = 0;
-    m_curr       = 0;
-    m_tex1First  = true;
-    m_timeout    = m_sharedData->delay;
+    m_fileIndex     = 0;
+    m_texture[0]    = 0;
+    m_texture[1]    = 0;
+    m_curr          = 0;
+    m_tex1First     = true;
+    m_timeout       = m_sharedData->delay;
     m_effectRunning = false;
     m_endOfShow     = false;
-
-    m_imageLoader = new SlideShowLoader(m_fileList, m_cacheSize, width(), height());
+    m_imageLoader   = new SlideShowLoader(m_fileList, m_cacheSize, width(), height(), m_sharedData);
 
     // --------------------------------------------------
 
@@ -160,7 +161,7 @@ SlideShowGL::SlideShowGL(const Q3ValueList<QPair<QString, int> >& fileList,
     m_timer = new QTimer(this);
 
     connect(m_timer, SIGNAL(timeout()),
-            SLOT(slotTimeOut()));
+            this, SLOT(slotTimeOut()));
 
     m_timer->setSingleShot(true);
 
@@ -171,7 +172,7 @@ SlideShowGL::SlideShowGL(const Q3ValueList<QPair<QString, int> >& fileList,
     m_mouseMoveTimer = new QTimer;
 
     connect(m_mouseMoveTimer, SIGNAL(timeout()),
-            SLOT(slotMouseMoveTimeOut()));
+            this, SLOT(slotMouseMoveTimeOut()));
 
     setMouseTracking(true);
 
@@ -187,8 +188,8 @@ SlideShowGL::~SlideShowGL()
     if (m_texture[1])
         glDeleteTextures(1, &m_texture[1]);
 
-    if (m_imageLoader)
-        delete m_imageLoader;
+    delete m_imageLoader;
+    delete m_mouseMoveTimer;
 }
 
 void SlideShowGL::initializeGL()
@@ -315,7 +316,6 @@ void SlideShowGL::mouseMoveEvent(QMouseEvent *e)
     }
 
     m_slidePlaybackWidget->show();
-
     m_playbackWidget->show();
 }
 
@@ -474,7 +474,6 @@ void SlideShowGL::previousFrame()
 
 void SlideShowGL::loadImage()
 {
-
     QImage image = m_imageLoader->getCurrent();
 
     if (!image.isNull())
@@ -520,10 +519,7 @@ void SlideShowGL::loadImage()
         glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
 
         glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
-
-
     }
-
 }
 
 void SlideShowGL::montage(QImage& top, QImage& bot)
@@ -553,14 +549,12 @@ void SlideShowGL::montage(QImage& top, QImage& bot)
 
     for (int y = sh; y < eh; y++)
     {
-
         bdata = (unsigned int*) bot.scanLine(y) + sw;
 
         for (int x = 0; x < tw; x++)
         {
             *(bdata++) = *(tdata++);
         }
-
     }
 }
 
@@ -628,7 +622,9 @@ void SlideShowGL::printProgress(QImage& layer)
 
 void SlideShowGL::printComments(QImage& layer)
 {
-    QString comments = m_commentsList[m_fileIndex];
+//    QString comments = m_commentsList[m_fileIndex];
+    KIPI::ImageInfo info = m_sharedData->interface->info(m_imageLoader->currPath());
+    QString comments = info.description();
 
     int yPos = 5; // Text Y coordinate
 
@@ -1207,7 +1203,6 @@ glTranslatef((m_dir % 2 == 0) ? ((m_dir == 2) ? 1 : -1) * t : 0.0,
 
     glEnd();
 
-
     m_i++;
 }
 
@@ -1224,9 +1219,9 @@ void SlideShowGL::effectSlide()
     if (m_i == 0)
         m_dir = 1 + (int)((4.0 * rand() / (RAND_MAX + 1.0)));
 
-    int a = (m_curr == 0) ? 1 : 0;
+    int a      = (m_curr == 0) ? 1 : 0;
 
-    int b =  m_curr;
+    int b      =  m_curr;
 
     GLuint& ta = m_texture[a];
 
@@ -1256,8 +1251,8 @@ void SlideShowGL::effectSlide()
     glMatrixMode(GL_MODELVIEW);
     glLoadIdentity();
     float trans = 2.0 / 100.0 * (float)m_i;
-glTranslatef((m_dir % 2 == 0) ? ((m_dir == 2) ? 1 : -1) * trans : 0.0,
-             (m_dir % 2 == 1) ? ((m_dir == 1) ? 1 : -1) * trans : 0.0,
+    glTranslatef((m_dir % 2 == 0) ? ((m_dir == 2) ? 1 : -1) * trans : 0.0,
+                 (m_dir % 2 == 1) ? ((m_dir == 1) ? 1 : -1) * trans : 0.0,
                  0.0);
 
     glBindTexture(GL_TEXTURE_2D, ta);
@@ -1315,7 +1310,6 @@ void SlideShowGL::effectFlutter()
         }
     }
 
-
     glBindTexture(GL_TEXTURE_2D, tb);
 
     glBegin(GL_QUADS);
@@ -1467,7 +1461,6 @@ void SlideShowGL::effectCube()
     glRotatef(xrot, 1.0f, 0.0f, 0.0f);
     glRotatef(yrot, 0.0f, 1.0f, 0.0f);
 
-
     glBindTexture(GL_TEXTURE_2D, 0);
     glBegin(GL_QUADS);
     {
