@@ -6,7 +6,8 @@
  * Date        : 2007-11-11
  * Description : a kipi plugin to slide images.
  *
- * Copyright (C) 2007-2008 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
+ * Copyright (C) 2007-2009 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
+ * Copyright (C) 2009 by Andi Clemens <andi dot clemens at gmx dot net>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -27,7 +28,7 @@
 #include <QImage>
 #include <QMatrix>
 #include <QPainter>
-#include <Q3ValueList>
+#include <QList>
 #include <QFileInfo>
 
 // KDE includes
@@ -43,20 +44,24 @@
 #include <libkdcraw/dcrawbinary.h>
 #endif
 
+// Local includes
+
+#include "common.h"
 
 namespace KIPIAdvancedSlideshowPlugin
 {
 
 LoadThread::LoadThread(LoadedImages* loadedImages, QMutex* imageLock, const KUrl path,
                        const int angle, int width, int height)
+          : QThread()
 {
 
-    m_path  =  path;
-    m_angle =  angle;
-    m_swidth = width;
-    m_sheight = height;
-    m_imageLock = imageLock;
-    m_loadedImages = loadedImages;
+    m_path          = path;
+    m_angle         = angle;
+    m_swidth        = width;
+    m_sheight       = height;
+    m_imageLock     = imageLock;
+    m_loadedImages  = loadedImages;
 }
 
 LoadThread::~LoadThread()
@@ -66,7 +71,7 @@ LoadThread::~LoadThread()
 void LoadThread::run()
 {
     QImage newImage;
-    
+
     // check if it's a RAW file.
 #if KDCRAW_VERSION < 0x000400
     QString rawFilesExt(KDcrawIface::DcrawBinary::instance()->rawFiles());
@@ -74,23 +79,25 @@ void LoadThread::run()
     QString rawFilesExt(KDcrawIface::KDcraw::rawFiles());
 #endif
     QFileInfo fileInfo(m_path.path());
-    if (rawFilesExt.toUpper().contains( fileInfo.suffix().toUpper() )) {
+    if (rawFilesExt.toUpper().contains(fileInfo.suffix().toUpper()))
+    {
         // it's a RAW file, use the libkdcraw loader
         KDcrawIface::KDcraw::loadDcrawPreview(newImage, m_path.path());
-    } else {
+    }
+    else
+    {
         // use the standard loader
-        newImage=QImage(m_path.path());
+        newImage = QImage(m_path.path());
     }
 
     // Rotate according to angle
-    if ( m_angle != 0 )
+    if (m_angle != 0)
     {
         QMatrix matrix;
-        matrix.rotate((double)m_angle);
-        newImage = newImage.transformed( matrix );
+        matrix.rotate((double) m_angle);
+        newImage = newImage.transformed(matrix);
     }
 
-
     newImage = newImage.scaled(m_swidth, m_sheight, Qt::KeepAspectRatio, Qt::SmoothTransformation);
 
     m_imageLock->lock();
@@ -100,36 +107,46 @@ void LoadThread::run()
 
 // -----------------------------------------------------------------------------------------
 
-SlideShowLoader::SlideShowLoader(FileList &pathList, uint cacheSize, int width, int height, int beginAtIndex)
+SlideShowLoader::SlideShowLoader(FileList &pathList, uint cacheSize, int width, int height,
+                                 SharedData* sharedData, int beginAtIndex)
 {
-
-    m_currIndex = beginAtIndex;
-    m_cacheSize = cacheSize;
-    m_pathList = pathList;
-    m_swidth = width;
-    m_sheight = height;
+    m_currIndex      = beginAtIndex;
+    m_cacheSize      = cacheSize;
+    m_pathList       = pathList;
+    m_swidth         = width;
+    m_sheight        = height;
     m_loadingThreads = new LoadingThreads();
-    m_loadedImages = new LoadedImages();
-    m_imageLock = new QMutex();
-    m_threadLock = new QMutex();
+    m_loadedImages   = new LoadedImages();
+    m_imageLock      = new QMutex();
+    m_threadLock     = new QMutex();
+    m_sharedData     = sharedData;
 
-    for ( uint i = 0; i < uint(m_cacheSize / 2) && i < uint(m_pathList.count()); i++ )
+    KUrl filePath;
+    int  angle = 0;
+
+    for (uint i = 0; i < uint(m_cacheSize / 2) && i < uint(m_pathList.count()); i++)
     {
-        LoadThread* newThread = new LoadThread(m_loadedImages, m_imageLock, KUrl(m_pathList[i].first),
-                                               m_pathList[i].second, m_swidth, m_sheight);
+        filePath = KUrl(m_pathList[i].first);
+        angle    = m_sharedData->interface->info(filePath).angle();
+
+        LoadThread* newThread = new LoadThread(m_loadedImages, m_imageLock,
+                                               filePath, angle, m_swidth, m_sheight);
         m_threadLock->lock();
-        m_loadingThreads->insert(m_pathList[i].first, newThread);
+        m_loadingThreads->insert(filePath, newThread);
         newThread->start();
         m_threadLock->unlock();
     }
 
-    for ( uint i = 0; i < ( m_cacheSize % 2 == 0 ? (m_cacheSize % 2) : uint(m_cacheSize / 2) + 1); i++ )
+    for (uint i = 0; i < (m_cacheSize % 2 == 0 ? (m_cacheSize % 2) : uint(m_cacheSize / 2) + 1); i++)
     {
         int toLoad = (m_currIndex - i) % m_pathList.count();
-        LoadThread* newThread = new LoadThread(m_loadedImages, m_imageLock, KUrl(m_pathList[toLoad].first),
-                                               m_pathList[toLoad].second, m_swidth, m_sheight);
+        filePath   = KUrl(m_pathList[toLoad].first);
+        angle      = m_sharedData->interface->info(filePath).angle();
+
+        LoadThread* newThread = new LoadThread(m_loadedImages, m_imageLock,
+                                               filePath, angle, m_swidth, m_sheight);
         m_threadLock->lock();
-        m_loadingThreads->insert(m_pathList[toLoad].first, newThread);
+        m_loadingThreads->insert(filePath, newThread);
         newThread->start();
         m_threadLock->unlock();
     }
@@ -138,47 +155,53 @@ SlideShowLoader::SlideShowLoader(FileList &pathList, uint cacheSize, int width,
 
 SlideShowLoader::~SlideShowLoader()
 {
-
     m_threadLock->lock();
     LoadingThreads::Iterator it;
 
-    for ( it = m_loadingThreads->begin(); it != m_loadingThreads->end(); ++it )
+    for (it = m_loadingThreads->begin(); it != m_loadingThreads->end(); ++it)
     {
         it.value()->wait();
         delete it.value();
-        m_loadingThreads->remove(it.key());
+        it = m_loadingThreads->erase(it);
     }
 
     m_threadLock->unlock();
 
+    delete m_loadedImages;
+    delete m_loadingThreads;
+    delete m_imageLock;
+    delete m_threadLock;
+
 }
 
 void SlideShowLoader::next()
 {
-    int victim = (m_currIndex - ( m_cacheSize % 2 == 0 ? (m_cacheSize / 2) - 1 : int(m_cacheSize / 2))) % m_pathList.count();
+    int victim = (m_currIndex - (m_cacheSize % 2 == 0 ?
+                 (m_cacheSize / 2) - 1 :
+                  int(m_cacheSize / 2))) % m_pathList.count();
     int newBorn = (m_currIndex + int(m_cacheSize / 2) + 1) % m_pathList.count();
 
-    if ( victim == newBorn ) return;
+    if (victim == newBorn)
+        return;
 
     m_threadLock->lock();
-
     m_imageLock->lock();
 
     m_loadingThreads->remove(m_pathList[victim].first);
-
     m_loadedImages->remove(m_pathList[victim].first);
 
     m_imageLock->unlock();
-
     m_threadLock->unlock();
 
-    LoadThread* newThread = new LoadThread(m_loadedImages, m_imageLock, KUrl(m_pathList[newBorn].first),
-                                           m_pathList[newBorn].second, m_swidth, m_sheight);
+    KUrl filePath = KUrl(m_pathList[newBorn].first);
+    int  angle    = m_sharedData->interface->info(filePath).angle();
+
+    LoadThread* newThread = new LoadThread(m_loadedImages, m_imageLock,
+                                           filePath, angle, m_swidth, m_sheight);
 
     m_threadLock->lock();
 
-    m_loadingThreads->insert(m_pathList[newBorn].first, newThread);
-
+    m_loadingThreads->insert(filePath, newThread);
     newThread->start();
 
     m_threadLock->unlock();
@@ -189,36 +212,36 @@ void SlideShowLoader::next()
 void SlideShowLoader::prev()
 {
     int victim = (m_currIndex + int(m_currIndex / 2)) % m_pathList.count();
-    int newBorn = (m_currIndex - ( (m_cacheSize & 2) == 0 ? (m_cacheSize / 2) : int(m_cacheSize / 2) + 1)) % m_pathList.count();
+    int newBorn = (m_currIndex - ((m_cacheSize & 2) == 0 ?
+                  (m_cacheSize / 2) :
+                   int(m_cacheSize / 2) + 1)) % m_pathList.count();
 
-    if ( victim == newBorn ) return;
+    if (victim == newBorn)
+        return;
 
     m_threadLock->lock();
-
     m_imageLock->lock();
 
     m_loadingThreads->remove(m_pathList[victim].first);
-
     m_loadedImages->remove(m_pathList[victim].first);
 
     m_imageLock->unlock();
-
     m_threadLock->unlock();
 
-    LoadThread* newThread = new LoadThread(m_loadedImages, m_imageLock, KUrl(m_pathList[newBorn].first),
-                                           m_pathList[newBorn].second, m_swidth, m_sheight);
+    KUrl filePath = KUrl(m_pathList[newBorn].first);
+    int  angle    = m_sharedData->interface->info(filePath).angle();
 
+    LoadThread* newThread = new LoadThread(m_loadedImages, m_imageLock,
+                                           filePath, angle, m_swidth, m_sheight);
 
     m_threadLock->lock();
 
-    m_loadingThreads->insert(m_pathList[newBorn].first, newThread);
-
+    m_loadingThreads->insert(filePath, newThread);
     newThread->start();
 
     m_threadLock->unlock();
 
     m_currIndex = (m_currIndex - 1) % m_pathList.count();
-
 }
 
 QImage SlideShowLoader::getCurrent()
@@ -229,7 +252,6 @@ QImage SlideShowLoader::getCurrent()
     QImage returned = (*m_loadedImages)[m_pathList[m_currIndex].first];
     m_imageLock->unlock();
 
-
     return returned;
 }
 
@@ -240,7 +262,7 @@ QString SlideShowLoader::currFileName()
 
 KUrl SlideShowLoader::currPath()
 {
-    return m_pathList[m_currIndex].first;
+    return KUrl(m_pathList[m_currIndex].first);
 }
 
 void SlideShowLoader::checkIsIn(int index)
@@ -249,15 +271,18 @@ void SlideShowLoader::checkIsIn(int index)
 
     if (m_loadingThreads->contains(m_pathList[index].first))
     {
-        if ( (*m_loadingThreads)[m_pathList[index].first]->isRunning() )
+        if ((*m_loadingThreads)[m_pathList[index].first]->isRunning())
             (*m_loadingThreads)[m_pathList[index].first]->wait();
 
         m_threadLock->unlock();
     }
     else
     {
-        LoadThread* newThread = new LoadThread(m_loadedImages, m_imageLock, KUrl(m_pathList[index].first),
-                                               m_pathList[index].second, m_swidth, m_sheight);
+        KUrl filePath = KUrl(m_pathList[index].first);
+        int  angle    = m_sharedData->interface->info(filePath).angle();
+
+        LoadThread* newThread = new LoadThread(m_loadedImages, m_imageLock,
+                                               filePath, angle, m_swidth, m_sheight);
 
         m_loadingThreads->insert(m_pathList[index].first, newThread);
         newThread->start();
@@ -266,4 +291,4 @@ void SlideShowLoader::checkIsIn(int index)
     }
 }
 
-}  // namespace KIPIAdvancedSlideshowPlugin
+} // namespace KIPIAdvancedSlideshowPlugin
