@@ -6,7 +6,8 @@
  * Date        : 2007-11-11
  * Description : a kipi plugin to slide images.
  *
- * Copyright (C) 2007-2008 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
+ * Copyright (C) 2007-2009 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
+ * Copyright (C) 2009 by Andi Clemens <andi dot clemens at gmx dot net>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -25,7 +26,7 @@
 
 // Qt includes
 
-#include <Q3ValueList>
+#include <QList>
 #include <QMap>
 #include <QMutex>
 #include <QImage>
@@ -36,14 +37,16 @@
 
 #include <kurl.h>
 
-typedef QPair<QString, int> FileAnglePair;
-typedef Q3ValueList<FileAnglePair> FileList;
+typedef QPair<QString, int>  FileAnglePair;
+typedef QList<FileAnglePair> FileList;
 
 namespace KIPIAdvancedSlideshowPlugin
 {
 
 typedef QMap<KUrl, QImage> LoadedImages;
 
+class SharedData;
+
 class LoadThread : public QThread
 {
 
@@ -76,13 +79,14 @@ class SlideShowLoader
 
 public:
 
-    SlideShowLoader(FileList &pathList, uint cacheSize, int width, int height, int beginAtIndex = 0);
+    SlideShowLoader(FileList &pathList, uint cacheSize, int width, int height,
+                    SharedData* sharedData, int beginAtIndex = 0);
     ~SlideShowLoader();
 
     void next();
     void prev();
 
-    QImage getCurrent();
+    QImage  getCurrent();
     QString currFileName();
     KUrl    currPath();
 
@@ -97,6 +101,8 @@ private:
     QMutex*         m_imageLock;
     QMutex*         m_threadLock;
 
+    SharedData*     m_sharedData;
+
     uint            m_cacheSize;
     int             m_currIndex;
     int             m_swidth;
