@@ -64,8 +64,8 @@ FilterImagesDialog::FilterImagesDialog( KUrl::List urlList, KIPI::Interface* int
     m_about = new KIPIPlugins::KPAboutData(ki18n("Batch image filtering"),
                                            QByteArray(),
                                            KAboutData::License_GPL,
-                                           ki18n("A Kipi plugin to batch filter images\n"
-                                                    "This plugin uses the \"convert\" program from \"ImageMagick\" package."),
+                                           ki18n("A Kipi plugin to batch filter images.\n"
+                                                    "This plugin uses the \"convert\" program from the \"ImageMagick\" package."),
                                            ki18n("(c) 2003-2009, Gilles Caulier\n"
                                                  "(c) 2007-2009, Aurélien Gateau"));
 
@@ -82,7 +82,7 @@ FilterImagesDialog::FilterImagesDialog( KUrl::List urlList, KIPI::Interface* int
 
     //---------------------------------------------
 
-    groupBox1->setTitle( i18n("Image Filtering Options") );
+    setOptionBoxTitle( i18n("Image Filtering Options") );
 
     m_labelType->setText( i18n("Filter:") );
 
@@ -96,7 +96,8 @@ FilterImagesDialog::FilterImagesDialog( KUrl::List urlList, KIPI::Interface* int
     m_Type->insertItem(i18n("Sharpen"));
     m_Type->insertItem(i18n("Unsharp"));         // 8
     m_Type->setCurrentText(i18n("Sharpen"));
-    whatsThis = i18n("<p>Select here the filter type for your images:</p>"
+    QString whatsThis = i18n(
+                     "<p>Select here the filter type for your images:</p>"
                      "<p>"
                      "<b>Add noise</b>: add artificial noise to an image.<br/>"
                      "<b>Antialias</b>: remove pixel aliasing.<br/>"
@@ -228,18 +229,7 @@ void FilterImagesDialog::readSettings(void)
     m_unsharpenPercent = group.readEntry("UnsharpenPercent", 3);
     m_unsharpenThreshold = group.readEntry("UnsharpenThreshold", 1);
 
-    if (group.readEntry("SmallPreview", "true") == "true")
-        m_smallPreview->setChecked( true );
-    else
-        m_smallPreview->setChecked( false );
-
-    m_overWriteMode->setCurrentIndex(group.readEntry("OverWriteMode", 2));  // 'Rename' per default...
-
-    if (group.readEntry("RemoveOriginal", "false") == "true")
-        m_removeOriginal->setChecked( true );
-    else
-        m_removeOriginal->setChecked( false );
-
+    readCommonSettings(group);
 }
 
 void FilterImagesDialog::saveSettings(void)
@@ -262,11 +252,7 @@ void FilterImagesDialog::saveSettings(void)
     group.writeEntry("UnsharpenPercent", m_unsharpenPercent);
     group.writeEntry("UnsharpenThreshold", m_unsharpenThreshold);
 
-    group.writeEntry("SmallPreview", m_smallPreview->isChecked());
-    group.writeEntry("OverWriteMode", m_overWriteMode->currentItem());
-    group.writeEntry("RemoveOriginal", m_removeOriginal->isChecked());
-
-
+    saveCommonSettings(group);
 }
 
 void FilterImagesDialog::initProcess(KProcess* proc, BatchProcessImagesItem *item,
@@ -274,7 +260,7 @@ void FilterImagesDialog::initProcess(KProcess* proc, BatchProcessImagesItem *ite
 {
     *proc << "convert";
 
-    if ( previewMode && m_smallPreview->isChecked() )    // Preview mode and small preview enabled !
+    if ( previewMode && smallPreview() )    // Preview mode and small preview enabled !
        {
        *m_PreviewProc << "-crop" << "300x300+0+0";
        m_previewOutput.append( " -crop 300x300+0+0 ");
