@@ -144,7 +144,7 @@ bool KPWriteImage::write2JPEG(const QString& destPath)
     FILE* file = fopen(QFile::encodeName(destPath), "wb");
     if (!file)
     {
-        kDebug(51000) << "Failed to open JPEG file for writing" << endl;
+        kDebug(51000) << "Failed to open JPEG file for writing" ;
         return false;
     }
 
@@ -258,7 +258,7 @@ bool KPWriteImage::write2PPM(const QString& destPath)
     FILE* file = fopen(QFile::encodeName(destPath), "wb");
     if (!file)
     {
-        kDebug(51000) << "Failed to open ppm file for writing" << endl;
+        kDebug(51000) << "Failed to open ppm file for writing" ;
         return false;
     }
 
@@ -336,7 +336,7 @@ bool KPWriteImage::write2PNG(const QString& destPath)
     FILE* file = fopen(QFile::encodeName(destPath), "wb");
     if (!file)
     {
-        kDebug(51000) << "Failed to open PNG file for writing" << endl;
+        kDebug(51000) << "Failed to open PNG file for writing" ;
         return false;
     }
 
@@ -509,7 +509,7 @@ bool KPWriteImage::write2TIFF(const QString& destPath)
     TIFF *tif = TIFFOpen(QFile::encodeName(destPath), "w");
     if (!tif)
     {
-        kDebug(51000) << "Failed to open TIFF file for writing" << endl;
+        kDebug(51000) << "Failed to open TIFF file for writing" ;
         return false;
     }
 
@@ -531,14 +531,18 @@ bool KPWriteImage::write2TIFF(const QString& destPath)
     //        http://www.awaresystems.be/imaging/tiff/tifftags/predictor.html
     TIFFSetField(tif, TIFFTAG_PREDICTOR,           2);
 
+    uint16 sampleinfo[1];
     if (d->hasAlpha)
     {
+        sampleinfo[0] = EXTRASAMPLE_ASSOCALPHA;
         TIFFSetField(tif, TIFFTAG_SAMPLESPERPIXEL, 4);
-        TIFFSetField(tif, TIFFTAG_EXTRASAMPLES,    EXTRASAMPLE_ASSOCALPHA);
+        TIFFSetField(tif, TIFFTAG_EXTRASAMPLES,    1, sampleinfo);
     }
     else
     {
+        sampleinfo[0] = EXTRASAMPLE_UNASSALPHA;
         TIFFSetField(tif, TIFFTAG_SAMPLESPERPIXEL, 3);
+        TIFFSetField(tif, TIFFTAG_EXTRASAMPLES,    1, sampleinfo);
     }
 
     TIFFSetField(tif, TIFFTAG_BITSPERSAMPLE,       (uint16)bitsDepth);
@@ -593,7 +597,7 @@ bool KPWriteImage::write2TIFF(const QString& destPath)
     uint8 *buf = (uint8 *)_TIFFmalloc(TIFFScanlineSize(tif));
     if (!buf)
     {
-        kDebug(51000) << "Cannot allocate memory buffer for main TIFF image." << endl;
+        kDebug(51000) << "Cannot allocate memory buffer for main TIFF image." ;
         TIFFClose(tif);
         return false;
     }
@@ -675,7 +679,7 @@ bool KPWriteImage::write2TIFF(const QString& destPath)
 
         if (!TIFFWriteScanline(tif, buf, y, 0))
         {
-            kDebug(51000) << "Cannot write main TIFF image to target file." << endl;
+            kDebug(51000) << "Cannot write main TIFF image to target file." ;
             _TIFFfree(buf);
             TIFFClose(tif);
             return false;
@@ -728,7 +732,7 @@ bool KPWriteImage::write2TIFF(const QString& destPath)
 
             if (!TIFFWriteScanline(tif, bufThumb, y, 0))
             {
-                kDebug(51000) << "Cannot write TIFF thumbnail to target file." << endl;
+                kDebug(51000) << "Cannot write TIFF thumbnail to target file." ;
                 _TIFFfree(bufThumb);
                 TIFFClose(tif);
                 return false;
@@ -807,7 +811,7 @@ void KPWriteImage::writeRawProfile(png_struct *ping, png_info *ping_info, char *
 
     const uchar hex[16] = {'0','1','2','3','4','5','6','7','8','9','a','b','c','d','e','f'};
 
-    kDebug(51000) << "Writing Raw profile: type= " << profile_type << ", length= " << length << endl;
+    kDebug(51000) << "Writing Raw profile: type= " << profile_type << ", length= " << length ;
 
     text               = (png_textp) png_malloc(ping, (png_uint_32) sizeof(png_text));
     description_length = strlen((const char *) profile_type);
@@ -987,7 +991,7 @@ void KPWriteImage::kipi_tiff_warning(const char* module, const char* format, va_
 #ifdef ENABLE_DEBUG_MESSAGES
     char message[4096];
     vsnprintf(message, 4096, format, warnings);
-    kDebug(51000) << module << "::" << message << endl;
+    kDebug(51000) << module << "::" << message ;
 #else
     Q_UNUSED(module);
     Q_UNUSED(format);
@@ -1000,7 +1004,7 @@ void KPWriteImage::kipi_tiff_error(const char* module, const char* format, va_li
 #ifdef ENABLE_DEBUG_MESSAGES
     char message[4096];
     vsnprintf(message, 4096, format, errors);
-    kDebug(51000) << module << "::" << message << endl;
+    kDebug(51000) << module << "::" << message ;
 #else
     Q_UNUSED(module);
     Q_UNUSED(format);
