@@ -23,9 +23,9 @@
 #ifndef DNGWRITTERHOST_H
 #define DNGWRITTERHOST_H
 
-// Local includes.
+// Local includes
 
-#include "dngwriterprivate.h"
+#include "dngwriter_p.h"
 
 namespace DNGIface
 {
