@@ -560,7 +560,7 @@ bool SimpleViewer::createIndex()
     if(indexTemplateName.isEmpty())
     {
         //TODO: errormsg
-        kDebug(51000) << "No indexTemplateName" << endl;
+        kDebug(51000) << "No indexTemplateName" ;
         return false;
     }
 
@@ -699,8 +699,8 @@ bool SimpleViewer::extractArchive(KZip &zip)
     QStringList names = zip.directory()->entries();
     if(names.count() != 1)
     {
-        kDebug(51000) << "Wrong SimpleViewer Version or corrupted archive" << endl;
-        kDebug(51000) << "Content of the archive root folder" << names << endl;
+        kDebug(51000) << "Wrong SimpleViewer Version or corrupted archive" ;
+        kDebug(51000) << "Content of the archive root folder" << names ;
         return false;
     }
 
@@ -708,7 +708,7 @@ bool SimpleViewer::extractArchive(KZip &zip)
     const KArchiveEntry *root = zip.directory()->entry(names[0]);
     if(!root || !root->isDirectory())
     {
-        kDebug(51000) << "could not open " << names[0] << " of zipname" << endl;
+        kDebug(51000) << "could not open " << names[0] << " of zipname" ;
         return false;
     }
 
@@ -722,7 +722,7 @@ bool SimpleViewer::extractArchive(KZip &zip)
         if(!extractFile(entry))
         {
             //TODO error msg
-            kDebug(51000) << "could not open " << *it << " of zipname" << endl;
+            kDebug(51000) << "could not open " << *it << " of zipname" ;
             return false;
         }
     }
