@@ -74,7 +74,7 @@ class FPhotoInfo;
 class FPhotoSet;
 class GPhoto;
 class GAlbum;
-class GAlbumViewItem;
+//class GAlbumViewItem;
 class ImagesList;
 
 class FlickrWindow : public KDialog
@@ -102,10 +102,11 @@ private slots:
 
     void slotCreateNewPhotoSet();
     void slotUserChangeRequest();
-    void slotListPhotoSetsSucceeded();
+    void populatePhotoSetComboBox();
     void slotAddPhotoNext();
     void slotAddPhotoSucceeded();
     void slotAddPhotoFailed(const QString& msg);
+    void slotAddPhotoSetSucceeded();
     void slotListPhotoSetsFailed(const QString& msg);
     void slotAddPhotoCancel();
     void slotAuthCancel();
@@ -140,7 +141,7 @@ private:
     QSpinBox                              *m_dimensionSpinBox;
     QSpinBox                              *m_imageQualitySpinBox;
 
-    QHash<int, GAlbumViewItem>             m_albumDict;
+//    QHash<int, GAlbumViewItem>             m_albumDict;
 
     QString                                m_token;
     QString                                m_username;
