@@ -64,7 +64,7 @@ K_EXPORT_PLUGIN ( GPSSyncFactory("kipiplugin_gpssync") )
 Plugin_GPSSync::Plugin_GPSSync(QObject *parent, const QVariantList &)
               : KIPI::Plugin( GPSSyncFactory::componentData(), parent, "GPSSync")
 {
-    kDebug( 51001 ) << "Plugin_GPSSync plugin loaded" << endl;
+    kDebug(51001) << "Plugin_GPSSync plugin loaded" ;
 }
 
 void Plugin_GPSSync::setup( QWidget* widget )
@@ -100,7 +100,7 @@ void Plugin_GPSSync::setup( QWidget* widget )
 
     addAction( m_action_geolocation );
 
-    KAction *m_actionKMLExport = actionCollection()->addAction("kmlexport");
+    m_actionKMLExport = actionCollection()->addAction("kmlexport");
     m_actionKMLExport->setText(i18n("KML Export..."));
     m_actionKMLExport->setIcon(KIcon("applications-internet"));
     connect(m_actionKMLExport, SIGNAL(triggered(bool)),
@@ -112,7 +112,7 @@ void Plugin_GPSSync::setup( QWidget* widget )
 
     if ( !m_interface )
     {
-        kError( 51000 ) << "Kipi interface is null!" << endl;
+        kError( 51000 ) << "Kipi interface is null!" ;
         return;
     }
 
@@ -250,8 +250,8 @@ void Plugin_GPSSync::slotGPSEdit()
             }
 
             if (!ret)
-                kDebug( 51000 ) << "Cannot set GPS location into file metadata from "
-                         << url.fileName() << endl;
+                kDebug(51000) << "Cannot set GPS location into file metadata from "
+                         << url.fileName() ;
 
             // Set kipi host GPS location
             attributes.clear();
@@ -322,7 +322,7 @@ void Plugin_GPSSync::slotGPSTrackListEdit()
 
     if (trackList.isEmpty())
     {
-        KMessageBox::sorry(0, i18n("No GPS location have been found in your pictures."));
+        KMessageBox::sorry(0, i18n("No GPS locations have been found in your pictures."));
         return;
     }
 
@@ -356,8 +356,8 @@ void Plugin_GPSSync::slotGPSTrackListEdit()
                 ret &= exiv2Iface.save(url.path());
 
                 if (!ret)
-                    kDebug( 51000 ) << "Cannot set GPS location into file metadata from "
-                             << url.fileName() << endl;
+                    kDebug(51000) << "Cannot set GPS location into file metadata from "
+                             << url.fileName() ;
 
                 // Set kipi host GPS location
                 attributes.clear();
@@ -406,8 +406,8 @@ void Plugin_GPSSync::slotGPSRemove()
         ret &= exiv2Iface.save(url.path());
 
         if (!ret)
-            kDebug( 51000 ) << "Cannot remove GPS location into file metadata from "
-                     << url.fileName() << endl;
+            kDebug(51000) << "Cannot remove GPS location into file metadata from "
+                     << url.fileName() ;
 
         // Remove kipi host GPS location
         QStringList list;
@@ -423,7 +423,7 @@ void Plugin_GPSSync::slotKMLExport()
 
     if ( !selection.isValid() )
     {
-        kDebug( 51000) << "No Selection!" << endl;
+        kDebug(51000) << "No Selection!" ;
     }
     else
     {
@@ -450,6 +450,6 @@ KIPI::Category Plugin_GPSSync::category( KAction* action ) const
     if ( action == m_actionKMLExport )
        return KIPI::ExportPlugin;
 
-    kWarning( 51000 ) << "Unrecognized action for plugin category identification" << endl;
+    kWarning( 51000 ) << "Unrecognized action for plugin category identification" ;
     return KIPI::ImagesPlugin; // no warning from compiler, please
 }
